@@ -4,7 +4,7 @@ import os
 import tempfile
 from multiprocessing.managers import SharedMemoryManager
 
-import gitlab
+from clients.gitlab import gitlab
 from filelock import FileLock
 from flasket import endpoint
 from flasket.clients.gitlab import HookEvents, webhook
@@ -19,7 +19,12 @@ def atomic_file_action(app, callback):
     filepath = os.path.join(tempfile.gettempdir(), f"gl-webhooks.jobs.{key}.json")
     lockfile = filepath + ".lock"
 
-    with FileLock(lockfile):
+    if callback:
+        lock = FileLock(lockfile)
+    else:
+        lock = contextlib.nullcontext()
+
+    with lock:
         data = {}
         with contextlib.suppress(FileNotFoundError) as ctx:
             with open(filepath) as fd:
@@ -41,13 +46,12 @@ def purge_jobs(data):
 
 # TODO: Move to controller
 def insert_job(app, body):
+    gl = gitlab(app)
+
     build_id = str(body["build_id"])
     build_status = body["build_status"]
     project_id = str(body["project_id"])
 
-    cfg = app.settings["gitlab"]
-    gl = gitlab.Gitlab(cfg["url"], private_token=cfg["token"])
-
     def action(data):
         if build_id not in data:
             data[build_id] = {}
@@ -70,15 +74,34 @@ def insert_job(app, body):
     data = atomic_file_action(app, action)
     pending = len([True for v in data.values() if v["status"] == "pending"])
     running = len([True for v in data.values() if v["status"] == "running"])
-    created = len([True for v in data.values() if v["status"] == "created"])
 
     data["pending"] = pending
     data["running"] = running
-    data["created"] = created
 
     return data, 200
 
 
+def insert_jobs_from_project(app, project_id):
+    data = {}
+
+    gl = gitlab(app)
+
+    try:
+        for job in gl.projects.get(project_id, lazy=True).jobs.list(iterator=True, scope=["running", "pending"]):
+            body = {
+                "build_id": job.id,
+                "build_status": job.status,
+                "project_id": project_id,
+            }
+            data, _ = insert_job(app, body)
+    except:
+        pass
+
+    if data:
+        return data, 200
+    return {}, 204
+
+
 @endpoint
 def monitor_purge(app, body):
     data = atomic_file_action(app, purge_jobs)
@@ -86,30 +109,24 @@ def monitor_purge(app, body):
 
 
 @endpoint
-def monitor_insert(app, body, project_id):
+def monitor_insert(app, body, project_id=0):
+    if project_id != 0:
+        return insert_jobs_from_project(app, project_id)
+
     data = {}
+    gl = gitlab(app)
 
-    cfg = app.settings["gitlab"]
-    gl = gitlab.Gitlab(cfg["url"], private_token=cfg["token"])
-
-    for job in gl.projects.get(project_id, lazy=True).jobs.list(iterator=True, scope=["running", "pending", "created"]):
-        body = {
-            "build_id": job.id,
-            "build_status": job.status,
-            "project_id": project_id,
-        }
-        data, _ = insert_job(app, body)
+    for project in gl.projects.list(iterator=True):
+        data = insert_jobs_from_project(app, project.id)
 
     if data:
         return data, 200
-    else:
-        return {}, 204
+    return {}, 204
 
 
 @endpoint
 def monitor_update(app, body):
-    cfg = app.settings["gitlab"]
-    gl = gitlab.Gitlab(cfg["url"], private_token=cfg["token"])
+    gl = gitlab(app)
 
     def action(data):
         for k, v in data.items():
